@@ -4,9 +4,9 @@ from cjdg_open_api.base import base
 
 
 class user(base):
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
-    def __init__(self, token, app_secret=None):
-        super().__init__(token, app_secret)
 
 # 新增激活码
     def saveCdkey(self,data):
