@@ -3,8 +3,9 @@ from .base import base
 
 
 class lecture(base):
-    def __init__(self, token):
-        super().__init__(token)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
+
 
     def getVideos(self, tagids, pageSize=100, nowPage=1):
         url = "http://client.supshop.cn/allstar/api/" + "lecture/getVideos"
