@@ -12,8 +12,8 @@ from .base import base
 
 
 class org(base):
-    def __init__(self, token, app_secret=None):
-        super().__init__(token, app_secret)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     # 组织结构:搜索
     def orglistOrgShop(self, data):
