@@ -5,13 +5,8 @@ from ..base import base
 
 
 class courseLibrary(base):
-    def __init__(self, token, app_secret=None):
-        """course library's init
-        Args:
-            token (str): cjdg access_token
-            app_secret (str, optional): cjdg app_secret. Defaults to None.
-        """
-        super().__init__(token, app_secret=app_secret)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def create(self, _id):
         pass
