@@ -6,8 +6,8 @@ from loguru import logger
 class lecture(base):
     url = "https://client.chaojidaogou.com/allstar/api/lecture/"
 
-    def __init__(self, token):
-        super().__init__(token)
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     def list(self, nowPage=1, pageSize=100, ordertype=3, orderflag=0, status=1, skillids=""):
         url = f"{self.url}getLecturerList"
