@@ -13,8 +13,10 @@ from .base import base
 
 
 class cjdgUserGroup(base):
-    def __init__(self, token, app_secret=None):
-        super().__init__(token, app_secret)
+
+
+    def __init__(self, token, domain=True, safe=False, app_secret=None):
+        super().__init__(token, domain, safe, app_secret)
 
     # 用户组查询
     def list(self, data):
